@@ -2,8 +2,8 @@
 /**
     Suggorgate splits
     *\file SurrogateSplits.c
-    *\author $Author: hothorn $
-    *\date $Date: 2011-05-06 17:01:10 +0200 (Fri, 06 May 2011) $
+    *\author $Author: thothorn $
+    *\date $Date: 2012-03-21 17:14:01 +0100 (Wed, 21 Mar 2012) $
 */
                 
 #include "party.h"
@@ -124,11 +124,6 @@ void C_surrogates(SEXP node, SEXP learnsample, SEXP weights, SEXP controls,
          cutpoint[j] = cp;
     }
 
-    /* <FIXME>
-      what happens when maxstat == 0 for all j?
-      in case order[j] is a nominal variable, line
-      130 will give an error
-    </FIXME> */
 
     /* order with respect to maximal statistic */
     rsort_with_index(maxstat, order, ninputs);
@@ -138,6 +133,8 @@ void C_surrogates(SEXP node, SEXP learnsample, SEXP weights, SEXP controls,
     /* the best `maxsurr' ones are implemented */
     for (j = 0; j < maxsurr; j++) {
 
+        if (is_nominal(inputs, order[j])) continue;
+        
         for (i = 0; i < 4; i++) twotab[i] = 0.0;
         cut = cutpoint[order[j] - 1];
         SET_VECTOR_ELT(S3get_surrogatesplits(node), j, 
